@@ -1,6 +1,6 @@
 import re
 from abc import ABC
-from datetime import date, datetime
+from datetime import date, datetime, time
 from decimal import Decimal
 
 from functools import partial
@@ -17,9 +17,8 @@ from testfixtures import (
     ShouldRaise,
     compare,
     generator,
-    singleton,
-    )
-from testfixtures.compat import PY_37_PLUS
+    singleton, mock_datetime,
+)
 from testfixtures.comparison import compare_sequence, compare_object
 from unittest import TestCase
 
@@ -70,7 +69,7 @@ def check_raises(x_=marker, y_=marker, message=None, regex=None,
         raise AssertionError('No exception raised!')
 
 
-class CompareHelper(object):
+class CompareHelper:
 
     def check_raises(self, *args, **kw):
         check_raises(*args, **kw)
@@ -204,16 +203,10 @@ class TestCompare(CompareHelper, TestCase):
     def test_exception_diff(self):
         e1 = ValueError('some message')
         e2 = ValueError('some other message')
-        if PY_37_PLUS:
-            self.check_raises(
-                e1, e2,
-                "ValueError('some message') != ValueError('some other message')"
-                )
-        else:
-            self.check_raises(
-                e1, e2,
-                "ValueError('some message',) != ValueError('some other message',)"
-                )
+        self.check_raises(
+            e1, e2,
+            "ValueError('some message') != ValueError('some other message')"
+            )
 
     def test_exception_diff_c_wrapper(self):
         e1 = ValueError('some message')
@@ -226,8 +219,9 @@ class TestCompare(CompareHelper, TestCase):
              "'args': ('some message',) (Comparison) "
              "!= ('some other message',) (actual)\n"
              "</C:builtins.ValueError>"
-             " != ValueError('some other message'{message})"
-             ).format(message='' if PY_37_PLUS else ','))
+             " != ValueError('some other message')"
+             )
+        )
 
     def test_sequence_long(self):
         self.check_raises(
@@ -707,9 +701,9 @@ class TestCompare(CompareHelper, TestCase):
 
     def test_sequence_and_generator_strict(self):
         expected = compile(
-            "\(1, 2, 3\) \(<(class|type) 'tuple'>\) \(expected\) != "
-            "<generator object (generator )?at... "
-            "\(<(class|type) 'generator'>\) \(actual\)"
+            r"\(1, 2, 3\) \(<(class|type) 'tuple'>\) \(expected\) != "
+            r"<generator object (generator )?at... "
+            r"\(<(class|type) 'generator'>\) \(actual\)"
             )
         self.check_raises(
             (1, 2, 3), generator(1, 2, 3),
@@ -745,10 +739,10 @@ class TestCompare(CompareHelper, TestCase):
 
     def test_iterable_and_generator_strict(self):
         expected = compile(
-            "range\(1, 4\) \(<(class|type) 'x?range'>\) != "
-            "<generator object (generator )?at... "
-            "\(<(class|type) 'generator'>\)"
-            )
+            r"range\(1, 4\) \(<(class|type) 'x?range'>\) != "
+            r"<generator object (generator )?at... "
+            r"\(<(class|type) 'generator'>\)"
+        )
         self.check_raises(
             range(1, 4), generator(1, 2, 3),
             regex=expected,
@@ -798,7 +792,7 @@ class TestCompare(CompareHelper, TestCase):
         self.check_raises(X, Y, expected)
 
     def test_new_style_classes_same(self):
-        class X(object):
+        class X:
             pass
         compare(X, X)
 
@@ -811,10 +805,10 @@ class TestCompare(CompareHelper, TestCase):
             "test_new_style_classes_different.<locals>.Y'>"
             )
 
-        class X(object):
+        class X:
             pass
 
-        class Y(object):
+        class Y:
             pass
         self.check_raises(X, Y, expected)
 
@@ -928,7 +922,7 @@ b
                     })
 
     def test_extra_comparers_leave_existing(self):
-        class MyObject(object):
+        class MyObject:
             def __init__(self, name):
                 self.name = name
 
@@ -1466,7 +1460,7 @@ b
     def test_dont_raise(self):
         self.assertEqual(compare('x', 'y', raises=False), "'x' != 'y'")
 
-    class OrmObj(object):
+    class OrmObj:
         def __init__(self, a):
             self.a = a
         def __eq__(self, other):
@@ -1531,7 +1525,7 @@ b
         )
 
     def test_nested_django_orm_in_object(self):
-        class MyObject(object):
+        class MyObject:
             def __init__(self, orm):
                 self.orm = orm
 
@@ -1610,7 +1604,7 @@ b
         )
 
     def test_calls_args_different_but_same_repr(self):
-        class Annoying(object):
+        class Annoying:
             def __init__(self, x):
                 self.x = x
             def __repr__(self):
@@ -1654,7 +1648,7 @@ b
         )
 
     def test_calls_nested_equal_sub_attributes(self):
-        class Annoying(object):
+        class Annoying:
             def __init__(self, x):
                 self.x = x
             def __repr__(self):
@@ -1740,7 +1734,7 @@ b
 
     def test_inherited_slots(self):
 
-        class Parent(object):
+        class Parent:
             __slots__ = ('a',)
 
         class Child(Parent):
@@ -1763,7 +1757,7 @@ b
 
     def test_empty_child_slots(self):
 
-        class Parent(object):
+        class Parent:
             __slots__ = ('a',)
 
             def __init__(self, a):
@@ -1776,7 +1770,7 @@ b
 
     def test_slots_and_attrs(self):
 
-        class Parent(object):
+        class Parent:
             __slots__ = ('a',)
 
         class Child(Parent):
@@ -1876,7 +1870,7 @@ b
 
     def test_repr_and_attributes_equal(self):
 
-        class Wut(object):
+        class Wut:
             def __repr__(self):
                 return 'Wut'
             def __eq__(self, other):
@@ -1896,7 +1890,7 @@ b
 
     def test_string_with_slotted(self):
 
-        class Slotted(object):
+        class Slotted:
             __slots__ = ['foo']
             def __init__(self, foo):
                 self.foo = foo
@@ -2075,7 +2069,7 @@ b
 
 class TestIgnore(CompareHelper):
 
-    class Parent(object):
+    class Parent:
         def __init__(self, id, other):
             self.id = id
             self.other = other
@@ -2112,9 +2106,9 @@ class TestIgnore(CompareHelper):
         )
 
 
-class TestCompareObject(object):
+class TestCompareObject:
 
-    class Thing(object):
+    class Thing:
         def __init__(self, **kw):
             for k, v in kw.items():
                 setattr(self, k, v)
@@ -2150,7 +2144,7 @@ class MyDerivedClass(BaseClass):
         self.thing = thing
 
 
-class ConcreteBaseClass(object): pass
+class ConcreteBaseClass: pass
 
 
 class ConcreteDerivedClass(ConcreteBaseClass):
@@ -2192,3 +2186,38 @@ class TestBaseClasses(CompareHelper):
             "attributes differ:\n"
             "'thing': 1 != 2"
         ))
+
+
+class TestDateAndTime:
+
+    def test_datetime_with_same_fold(self):
+        compare(datetime(2000, 1, 1, fold=0), datetime(2000, 1, 1, fold=0))
+
+    def test_time_with_same_fold(self):
+        compare(time(fold=0), time(fold=0))
+
+    def test_datetime_with_different_fold(self):
+        # because Python is insane...
+        compare(datetime(2000, 1, 1, fold=1), datetime(2000, 1, 1, fold=0))
+
+    def test_time_with_different_fold(self):
+        # because Python is insane...
+        compare(time(fold=1), time(fold=0))
+
+    def test_datetime_with_same_fold_strict(self):
+        compare(datetime(2000, 1, 1, fold=0), datetime(2000, 1, 1, fold=0), strict=True)
+
+    def test_time_with_same_fold_strict(self):
+        compare(time(fold=0), time(fold=0), strict=True)
+
+    def test_datetime_with_different_fold_strict(self):
+        with ShouldAssert(
+                'datetime.datetime(2000, 1, 1, 0, 0, fold=1) != datetime.datetime(2000, 1, 1, 0, 0)'
+        ):
+            compare(datetime(2000, 1, 1, fold=1), datetime(2000, 1, 1, fold=0), strict=True)
+
+    def test_time_with_different_fold_strict(self):
+        with ShouldAssert(
+                'datetime.time(0, 0, fold=1) != datetime.time(0, 0)'
+        ):
+            compare(time(fold=1), time(fold=0), strict=True)
